package com.autentia.tutoriales;

import com.sun.lwuit.*;
import com.sun.lwuit.events.ActionEvent;
import com.sun.lwuit.events.ActionListener;
import com.sun.lwuit.layouts.*;
import com.sun.lwuit.util.Resources;

/**
 * Ventana principal
 * @author Carlos García. Autentia.
 */
public class MainUI extends Form implements ActionListener {

    private LWUITDemoMidlet midlet;
    private Button          btnExit;

    /**
     * Constructor
     */
    public MainUI(LWUITDemoMidlet midlet){
        super();
        this.midlet = midlet;
        this.createUI();
    }

    /**
     * Crea y configura el interface gráfico
     */
    private void createUI(){
        Resources  resources  = this.midlet.getResources();
        TabbedPane tabbedPane = new TabbedPane();

        // El título de la pantalla
        Image imagen     = resources.getImage("logo");
        Label titlePanel = new Label(imagen);
        titlePanel.setAlignment(CENTER);

        // El contenido centrar de la pantalla
        Container panel1  = new Container();
        panel1.setLayout(new BoxLayout(BoxLayout.Y_AXIS));
        panel1.addComponent(new Label("Label"));
        panel1.addComponent(new CheckBox("Checkbox"));
        panel1.addComponent(new ComboBox(new String[]{"ComboBox1", "ComboBox2"}));
        panel1.addComponent(this.getRadioButtonPanel());

        Container buttonsPanel = new Container();
        btnExit = new Button("Salir");
        buttonsPanel.addComponent(btnExit);


        tabbedPane.addTab("Ficha 1", panel1);
        tabbedPane.addTab("Ficha 2", new Container());
        tabbedPane.addTab("Ficha 3", new Container());

        // Añadimos todos los paneles a la ventana
        Container contentPane = this.getContentPane();
        contentPane.setLayout(new BorderLayout());
        contentPane.addComponent(BorderLayout.NORTH,  titlePanel);
        contentPane.addComponent(BorderLayout.CENTER, tabbedPane);
        contentPane.addComponent(BorderLayout.SOUTH,  buttonsPanel);

        // Configuramos la ventana
        this.setTitle("Ejemplo LWUIT");

        // Configuramos los eventos
        btnExit.addActionListener(this);
    }

    /**
     * Crea un panel con dos radio button que forman parte del mismo grupo
     * A modo didactico lo pongo en otro método para que quede más claro.
     */
    private Container getRadioButtonPanel(){
        Container radioButtonPanel = new Container(new GridLayout(1, 2));

        RadioButton radio1 = new RadioButton("Radio1");
        RadioButton radio2 = new RadioButton("Radio2");
        ButtonGroup group1 = new ButtonGroup();
        group1.add(radio1);
        group1.add(radio2);

        radioButtonPanel.addComponent(radio1);
        radioButtonPanel.addComponent(radio2);

        return radioButtonPanel;
    }

    /**
     * Muestra un cuadro de diálogo
     * @param Texto del cuadro de diálogo
     */
    public void showDialog(String text){
        TextArea  message = new TextArea(text, 2, 50);
        Command[] cmds    = new Command[] { new Command("Aceptar")};
        Dialog.show("Atención",  message, cmds);
    }

    /**
     * Implementación de ActionListener.
     * Tratamiento de eventos
     */
    public void actionPerformed(ActionEvent event) {
        Object source = event.getSource();

        // Si ha pulsado el botón de salir, mostramos un cuadro de
        // diálogo y salimos
        if (source == this.btnExit) {
            this.showDialog("Hasta pronto!!");
            this.midlet.destroyApp(false);
        }
    }
}
